# CausalImpact

## An R package for causal inference using Bayesian structural time-series models

This R package implements an approach to estimating the causal effect of a
designed intervention on a time series. For example, how many additional daily
clicks were generated by an advertising campaign? Answering a question like this
can be difficult when a randomized experiment is not available. The package aims
to address this difficulty using a structural Bayesian time-series model to
estimate how the response metric might have evolved after the intervention if
the intervention had not occurred.

As with all approaches to causal inference on non-experimental data, valid
conclusions require strong assumptions. The CausalImpact package, in particular,
assumes that the outcome time series can be explained in terms of a set of
control time series that were themselves not affected by the intervention.
Furthermore, the relation between treated series and control series is assumed
to be stable during the post-intervention period. Understanding and checking
these assumptions for any given application is critical for obtaining valid
conclusions.

## Installation

```r
install.packages("CausalImpact")
library(CausalImpact)
```

## Getting started

[Video tutorial](https://www.youtube.com/watch?v=GTgZfCltMm8)

[Documentation and examples](https://google.github.io/CausalImpact/CausalImpact.html)

## Further resources

*   Manuscript:
    [Brodersen et al., Annals of Applied Statistics (2015)](http://research.google.com/pubs/pub41854.html)

*   For questions on the statistics behind CausalImpact:
    [Cross Validated](http://stats.stackexchange.com/questions/tagged/causalimpact)

*   For questions on how to use the CausalImpact R package:
    [Stack Overflow](http://stackoverflow.com/questions/tagged/causalimpact)

*   [Bug reports](https://github.com/google/CausalImpact/issues)
